@@ -698,7 +698,7 @@ add_connection_item (NMDevice *device,
 	gtk_widget_show (item);
 }
 
-static void
+static gboolean
 add_menu_item (NMDevice *device,
                gboolean multiple_devices,
                const GPtrArray *connections,
@@ -715,7 +715,7 @@ add_menu_item (NMDevice *device,
 	if (!info) {
 		g_warning ("ModemManager is not available for modem at %s",
 		           nm_device_get_udi (device));
-		return;
+		return FALSE;
 	}
 
 	if (multiple_devices) {
@@ -794,6 +794,8 @@ add_menu_item (NMDevice *device,
 			add_connection_item (device, NULL, item, menu, applet);
 		}
 	}
+
+	return TRUE;
 }
 
 /********************************************************************/
@@ -803,11 +805,11 @@ notify_connected (NMDevice *device,
                   const char *msg,
                   NMApplet *applet)
 {
-	applet_do_notify_with_pref (applet,
-	                            _("Connection Established"),
-	                            msg ? msg : _("You are now connected to the Mobile Broadband network."),
-	                            "nm-device-wwan",
-	                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
+	applet_do_notify (applet,
+	                  _("Connection Established"),
+	                  msg ? msg : _("You are now connected to the Mobile Broadband network."),
+	                  "nm-device-wwan",
+	                  PREF_DISABLE_CONNECTED_NOTIFICATIONS);
 }
 
 /********************************************************************/
@@ -944,17 +946,17 @@ modem_state_changed (MMModem *object,
 		/* Notify about new registration info */
 		mb_state = broadband_state_to_mb_state (info);
 		if (mb_state == MB_STATE_HOME) {
-			applet_do_notify_with_pref (info->applet,
-			                            _("Mobile Broadband network."),
-			                            _("You are now registered on the home network."),
-			                            signal_strength_icon,
-			                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
+			applet_do_notify (info->applet,
+			                  _("Mobile Broadband network."),
+			                  _("You are now registered on the home network."),
+			                  signal_strength_icon,
+			                  PREF_DISABLE_CONNECTED_NOTIFICATIONS);
 		} else if (mb_state == MB_STATE_ROAMING) {
-			applet_do_notify_with_pref (info->applet,
-			                            _("Mobile Broadband network."),
-			                            _("You are now registered on a roaming network."),
-			                            signal_strength_icon,
-			                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
+			applet_do_notify (info->applet,
+			                  _("Mobile Broadband network."),
+			                  _("You are now registered on a roaming network."),
+			                  signal_strength_icon,
+			                  PREF_DISABLE_CONNECTED_NOTIFICATIONS);
 		}
 	}
 }
